@@ -140,11 +140,11 @@ class Constellation(ListEnum):
     VIS1 = "Vision-1"
     """Vision-1"""
 
-    RCM = "RADARSAT-Constellation Mission"
-    """RADARSAT-Constellation Mission"""
+    GS2 = "GEOSAT-2"
+    """GEOSAT-2 (ex. DEIMOS-2)"""
 
-    MAXAR = "Maxar"
-    """Maxar (not a real constellation, but used as a template for every Maxar products)"""
+    HLS = "HLS"
+    """Harmonized Landsat-Sentinel"""
 
     QB = "QuickBird"
     """QuickBird"""
@@ -164,6 +164,9 @@ class Constellation(ListEnum):
     WV04 = "WorldView-4"
     """WorldView-4"""
 
+    RCM = "RADARSAT-Constellation Mission"
+    """RADARSAT-Constellation Mission"""
+
     ICEYE = "ICEYE"
     """ICEYE"""
 
@@ -182,6 +185,9 @@ class Constellation(ListEnum):
     SPOT45 = "Spot-4/5"
     """SPOT-4/5 (not a real constellation, but used as a template for SPOT4/5 products)"""
 
+    MAXAR = "Maxar"
+    """Maxar (not a real constellation, but used as a template for every Maxar products)"""
+
     CUSTOM = "CUSTOM"
     """Custom stack"""
 
@@ -240,6 +246,8 @@ CONSTELLATION_REGEX = {
         r"\d{13}_\d{2}",
         r"SV1-0[1-4]_\d{8}_L(1B|2A)\d{10}_\d{13}_\d{2}-(MUX|PSH)\.xml",
     ],
+    Constellation.HLS: r"HLS\.[LS]30\.T\d{2}\w{3}\.\d{7}T\d{6}\.v2\.0",
+    Constellation.GS2: r"DE2_(PM4|PSH|PS3|PS4|MS4|PAN)_L1[A-D]_\d{6}_\d{8}T\d{6}_\d{8}T\d{6}_DE2_\d{5}_.{4}",
 }
 
 MTD_REGEX = {
@@ -303,6 +311,8 @@ MTD_REGEX = {
     Constellation.ICEYE: r"ICEYE_(X\d{1,}_|)(SLC|GRD)_((SM|SL|SC)H*|SLEA)_\d{5,}_\d{8}T\d{6}\.xml",
     Constellation.SAOCOM: r"S1[AB]_OPER_SAR_EOSSP__CORE_L1[A-D]_OL(F|VF)_\d{8}T\d{6}.xemt",
     Constellation.SV1: r"SV1-0[1-4]_\d{8}_L(1B|2A)\d{10}_\d{13}_\d{2}-(MUX|PSH)\.xml",
+    Constellation.HLS: rf"{CONSTELLATION_REGEX[Constellation.HLS]}\.Fmask\.tif",
+    Constellation.GS2: rf"{CONSTELLATION_REGEX[Constellation.GS2]}\.dim",
     Constellation.SPOT45: {
         "nested": -1,  # File that can be found at any level (product/**/file)
         "regex": [
@@ -375,7 +385,7 @@ class Reader:
         def _compile_(regex_str: str):
             return re.compile(f"{prefix}{regex_str}{suffix}")
 
-        # Case folder is not enough to identify the products (ie. COSMO Skymed)
+        # Case folder is not enough to identify the products (i.e. COSMO Skymed)
         if isinstance(regex, list):
             comp = [_compile_(regex) for regex in regex]
         else:
@@ -685,9 +695,13 @@ def is_filename_valid(
         bool: True if the filename corresponds to the given satellite regex
     """
     product_path = AnyPath(product_path)
-    product_file_name = files.get_filename(product_path)
+    # Handle HLS folders...
+    if product_path.is_dir() and product_path.suffix in [".0"]:
+        product_file_name = product_path.name
+    else:
+        product_file_name = files.get_filename(product_path)
 
-    # Case folder is not enough to identify the products (ie. COSMO Skymed)
+    # Case folder is not enough to identify the products (i.e. COSMO Skymed)
     # WARNING: Two level max for the moment
     is_valid = bool(regex[0].match(product_file_name))
     if is_valid and len(regex) > 1:
