@@ -81,7 +81,7 @@ def get_data_dir() -> Union[CloudPath, Path]:
         else:
             data_dirs = AnyPath("/").glob("**/eoreader/data")
 
-        # Look for non empty directories
+        # Look for non-empty directories
         for ddir in data_dirs:
             if len(os.listdir(ddir)) > 0:
                 data_dir = ddir
@@ -110,17 +110,17 @@ def get_split_name(name: str) -> list:
 def use_dask():
     """Use Dask or not"""
     # Check environment variable
-    use_dask = os.getenv(USE_DASK, "0").lower() in ("1", "true")
+    _use_dask = os.getenv(USE_DASK, "0").lower() in ("1", "true")
 
     # Check installed libs
-    if use_dask:
+    if _use_dask:
         try:
             import dask
             import distributed
         except ImportError:
-            use_dask = False
+            _use_dask = False
 
-    return use_dask
+    return _use_dask
 
 
 def read(
@@ -154,7 +154,7 @@ def read(
         indexes (Union[int, list]): Indexes to load. Load the whole array if None.
         **kwargs: Optional keyword arguments to pass into rioxarray.open_rasterio().
     Returns:
-        xr.DataArray: Masked xarray corresponding to the raster data and its meta data
+        xr.DataArray: Masked xarray corresponding to the raster data and its metadata
 
     """
     if use_dask():
@@ -408,7 +408,7 @@ def simplify(footprint_fct: Callable):
     Simplify footprint decorator
 
     Args:
-        function (Callable): Function to decorate
+        footprint_fct (Callable): Function to decorate
 
     Returns:
         Callable: decorated function
@@ -416,7 +416,7 @@ def simplify(footprint_fct: Callable):
 
     @wraps(footprint_fct)
     def simplify_wrapper(self):
-        """ Simplify footprint wrapper """
+        """Simplify footprint wrapper"""
         footprint = footprint_fct(self)
         return simplify_footprint(footprint, self.resolution)
 
